#
# spec file for package python-opentelemetry-api
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-opentelemetry-api
Version:        1.17.0
Release:        1.3
Summary:        OpenTelemetry Python API
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python/tree/master/opentelemetry-api
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-api/opentelemetry_api-%{version}.tar.gz
BuildRequires:  %{python_module Deprecated}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Note: If python3-aiocontextvars is not available, the error message will
# be confusing: https://github.com/openSUSE/obs-build/issues/685
BuildRequires:  (python3-aiocontextvars if python3-base < 3.7)
BuildArch:      noarch
Requires:       python-Deprecated
Requires:       python-importlib-metadata
Requires:       python-setuptools
%if %{python_version_nodots} < 37
Requires:       python-aiocontextvars
%endif
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
OpenTelemetry Python API

%prep
%setup -q -n opentelemetry_api-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# ignore some tests because we don't have opentelemetry.test module
# gh#open-telemetry/opentelemetry-python#2263
%pytest --ignore tests/util/test_once.py --ignore tests/logs/test_logger_provider.py --ignore tests/metrics/test_meter_provider.py --ignore tests/trace/test_globals.py --ignore tests/trace/test_proxy.py

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/opentelemetry
%{python_sitelib}/opentelemetry_api-%{version}*-info

%changelog
* Thu May 11 2023 Daniel Garcia <daniel.garcia@suse.com>
- Ignore some tests because there's no opentelemetry-test-util module
  gh#open-telemetry/opentelemetry-python#2263
- Update to 1.17.0:
  * Implement LowMemory temporality (#3223)
  * PeriodicExportingMetricReader will continue if collection times out (#3100)
  * Fix formatting of ConsoleMetricExporter. (#3197)
  * Fix use of built-in samplers in SDK configuration (#3176)
  * Implement shutdown procedure forOTLP grpc exporters (#3138)
  * Add exponential histogram (#2964)
  * Add OpenCensus trace bridge/shim (#3210)
  * A lot more changes in previous releases can be found at
  https://github.com/open-telemetry/opentelemetry-python/blob/main/CHANGELOG.md#version-1170038b0-2023-03-22
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Jan 16 2022 Ben Greiner <code@bnavigator.de>
- Remove obsolete but unresolvable python36 requirement
* Thu Nov  4 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.5.0
  - Add pre and post instrumentation entry points (#1983)
  - Fix documentation on well known exporters and variable OTEL_TRACES_EXPORTER
    which were misnamed (#2023)
  - `opentelemetry-sdk` `get_aggregated_resource()` returns default resource and
    service name whenever called (#2013)
  - `opentelemetry-distro` & `opentelemetry-sdk` Moved Auto Instrumentation Configurator
    code to SDK to let distros use its default implementation (#1937)
  - Add Trace ID validation to meet TraceID spec (#1992)
  - Fixed Python 3.10 incompatibility in `opentelemetry-opentracing-shim` tests (#2018)
  - `opentelemetry-sdk` added support for `OTEL_SPAN_ATTRIBUTE_VALUE_LENGTH_LIMIT` (#2044)
  - `opentelemetry-sdk` Fixed bugs (#2041, #2042 & #2045) in Span Limits (#2044)
  - `opentelemetry-sdk` Add support for `OTEL_ATTRIBUTE_VALUE_LENGTH_LIMIT` env var (#2056)
  - `opentelemetry-sdk` Treat limit even vars set to empty values as unset/unlimited. (#2054)
  - `opentelemetry-api` Attribute keys must be non-empty strings. (#2057)
- from version 1.4.0
  + Added
  - Moved `opentelemetry-instrumentation` to core repository. (#1959)
  - Add support for OTLP Exporter Protobuf over HTTP (#1868)
  - Dropped attributes/events/links count available exposed on ReadableSpans. (#1893)
  - Added dropped count to otlp, jaeger and zipkin exporters. (#1893)
  - Give OTLPHandler the ability to process attributes (#1952)
  - Add global LogEmitterProvider and convenience function get_log_emitter (#1901)
  - Add OTLPHandler for standard library logging module (#1903)
  + Changed
  - Updated `opentelemetry-opencensus-exporter` to use `service_name` of spans
    instead of resource (#1897)
  - Added descriptions to the env variables mentioned in the opentelemetry-specification
    (#1898)
  - Ignore calls to `Span.set_status` with `StatusCode.UNSET` and also if previous
    status already had `StatusCode.OK`. (#1902)
  - Attributes for `Link` and `Resource` are immutable as they are for `Event`, which
    means any attempt to modify attributes directly will result in a `TypeError` exception.
    (#1909)
  - Added `BoundedAttributes` to the API to make it available for `Link` which is defined
    in the API. Marked `BoundedDict` in the SDK as deprecated as a result. (#1915)
  - Fix OTLP SpanExporter to distinguish spans based off Resource and InstrumentationInfo
    (#1927)
  - Updating dependency for opentelemetry api/sdk packages to support major version
    instead of pinning to specific versions. (#1933)
  - `opentelemetry-semantic-conventions` Generate semconv constants update for OTel
    Spec 1.5.0 (#1946)
  + Fixed
  - Updated `opentelementry-opentracing-shim` `ScopeShim` to report exceptions in
    opentelemetry specification format, rather than opentracing spec format. (#1878)
- from version 1.3.0
  + Added
  - Allow span limits to be set programatically via TracerProvider. (#1877)
  - Added support for CreateKey functionality. (#1853)
  + Changed
  - Updated get_tracer to return an empty string when passed an invalid name (#1854)
  - Changed AttributeValue sequences to warn mypy users on adding None values to array
    (#1855)
  - Fixed exporter OTLP header parsing to match baggage header formatting. (#1869)
  - Added optional `schema_url` field to `Resource` class (#1871)
  - Update protos to latest version release 0.9.0 (#1873)
- from version 1.2.0
  + Added
  - Added example for running Django with auto instrumentation. (#1803)
  - Added `B3SingleFormat` and `B3MultiFormat` propagators to the
    `opentelemetry-propagator-b3` package. (#1823)
  - Added support for OTEL_SERVICE_NAME. (#1829)
  - Lazily read/configure limits and allow limits to be unset. (#1839)
  - Added support for OTEL_EXPORTER_JAEGER_TIMEOUT (#1863)
  + Changed
  - Fixed OTLP gRPC exporter silently failing if scheme is not specified
    in endpoint. (#1806)
  - Rename CompositeHTTPPropagator to CompositePropagator as per specification.
    (#1807)
  - Propagators use the root context as default for `extract` and do not modify
    the context if extracting from carrier does not work. (#1811)
  - Fixed `b3` propagator entrypoint to point to `B3SingleFormat` propagator.
    (#1823)
  - Added `b3multi` propagator entrypoint to point to `B3MultiFormat` propagator.
    (#1823)
  - Improve warning when failing to decode byte attribute (#1810)
  - Fixed inconsistency in parent_id formatting from the ConsoleSpanExporter
    (#1833)
  - Include span parent in Jaeger gRPC export as `CHILD_OF` reference (#1809)
  - Fixed sequence values in OTLP exporter not translating (#1818)
  - Update transient errors retry timeout and retryable status codes (#1842)
  - Apply validation of attributes to `Resource`, move attribute related logic
    to separate package. (#1834)
  - Fix start span behavior when excess links and attributes are included (#1856)
  +  Removed
  - Moved `opentelemetry-instrumentation` to contrib repository. (#1797)
* Fri May  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.1.0
  + Added
  - Added py.typed file to every package. This should resolve a bunch of mypy
    errors for users. (#1720)
  - Add auto generated trace and resource attributes semantic conventions (#1759)
  - Added SpanKind to should_sample parameters, suggest using parent span
    context's tracestate instead of manually passed in tracestate in
    should_sample (#1764)
  - Added experimental HTTP back propagators. (#1762)
  - Adjust B3Format propagator to be spec compliant by not modifying context
    when propagation headers are not present/invalid/empty (#1728)
  - Silence unnecessary warning when creating a new Status object without description. (#1721)
  - Update bootstrap cmd to use exact version when installing instrumentation packages. (#1722)
  - Fix B3 propagator to never return None. (#1750)
  - Added ProxyTracerProvider and ProxyTracer implementations to allow fetching provider
    and tracer instances before a global provider is set up. (#1726)
  - Added __contains__ to opentelementry.trace.span.TraceState. (#1773)
    opentelemetry-opentracing-shim Fix an issue in the shim where a Span was being wrapped
    in a NonRecordingSpan when it wasn't necessary. (#1776)
  - OTLP Exporter now uses the scheme in the endpoint to determine whether to establish
    a secure connection or not. (#1771)
- from version 1.10a0
  + This release adds the experimental metrics API/SDK and will include the following packages:
  - opentelemetry-exporter-prometheus
  - opentelemetry-api
  - opentelemetry-sdk
  - opentelemetry-exporter-otlp-proto-grpc
  - opentelemetry-exporter-otlp
- from version 1.0.0
  + NOTE: As part of this release, all old versions have been removed for packages
    prefixed with opentelemetry-ext-
  + Added
  - Document how to work with fork process web server models(Gunicorn, uWSGI etc...)
    (#1609)
  - Add max_attr_value_length support to Jaeger exporter (#1633)
  - Moved use_span from Tracer to opentelemetry.trace.use_span. (#1668)
  - opentelemetry.trace.use_span() will now overwrite previously set status on span
    in case an exception is raised inside the context manager and set_status_on_exception
    is set to True. (#1668)
  - Add udp_split_oversized_batches support to jaeger exporter (#1500)
  + Changed
  - remove service_name from constructor of jaeger and opencensus exporters and
    use of env variable OTEL_PYTHON_SERVICE_NAME ([#1669])(#1669)
  - Rename IdsGenerator to IdGenerator (#1651)
  - Make TracerProvider's resource attribute private (#1652)
  - Rename Resource's create_empty to get_empty (#1653)
  - Renamed BatchExportSpanProcessor to BatchSpanProcessor and SimpleExportSpanProcessor
    to SimpleSpanProcessor (#1656)
  - Rename DefaultSpan to NonRecordingSpan (#1661)
  - Fixed distro configuration with OTEL_TRACES_EXPORTER env var set to otlp (#1657)
  - Moving Getter, Setter and TextMapPropagator out of opentelemetry.trace.propagation
    and into opentelemetry.propagators (#1662)
  - Rename BaggagePropagator to W3CBaggagePropagator (#1663)
  - Rename JaegerSpanExporter to JaegerExporter and rename ZipkinSpanExporter to
    ZipkinExporter (#1664)
  - Expose StatusCode from the opentelemetry.trace module (#1681)
  - Status now only sets description when status_code is set to StatusCode.ERROR (#1673)
  - Update OTLP exporter to use OTLP proto 0.7.0 (#1674)
  - Remove time_ns from API and add a warning for older versions of Python (#1602)
  - Hide implementation classes/variables in api/sdk (#1684)
  - Cleanup OTLP exporter compression options, add tests (#1671)
  - Initial documentation for environment variables (#1680)
  - Change Zipkin exporter to obtain service.name from span (#1696)
  - Split up opentelemetry-exporter-jaeger package into opentelemetry-exporter-jaeger-proto-grpc
    and opentelemetry-exporter-jaeger-thrift packages to reduce dependencies for each one. (#1694)
  - Added opentelemetry-exporter-otlp-proto-grpc and changed opentelemetry-exporter-otlp to
    install it as a dependency. This will allow for the next package/protocol to also be in
    its own package. (#1695)
  - Change Jaeger exporters to obtain service.name from span (#1703)
  - Fixed an unset OTEL_TRACES_EXPORTER resulting in an error (#1707)
  - Split Zipkin exporter into opentelemetry-exporter-zipkin-json and opentelemetry-exporter-zipkin-
    proto-http packages to reduce dependencies. The opentelemetry-exporter-zipkin installs both. (#1699)
  - Make setters and getters optional (#1690)
  + Removed
  - Removed unused get_hexadecimal_trace_id and get_hexadecimal_span_id methods. (#1675)
  - Remove OTEL_EXPORTER_*_ INSECURE env var (#1682)
  - Removing support for Python 3.5 (#1706)
- from version 0.19b0
  + Changed
  - remove service_name from constructor of jaeger and opencensus exporters and
    use of env variable OTEL_PYTHON_SERVICE_NAME ([#1669])(#1669)
  - Rename IdsGenerator to IdGenerator (#1651)
  + Removed
  - Removing support for Python 3.5 (#1706)
- from version 0.18b0
  + Release only affects Opentelemetry components listed below:
  - opentelemetry-distro
  - opentelemetry-exporter-opencensus
  - opentelemetry-instrumentation
  - opentelemetry-opentracing-shim
  + Added
  - Add urllib to opentelemetry-bootstrap target list ([#1584])(#1584)
- from version 1.0.0rc1
  + Release only affects core Opentelemetry components listed below:
  - opentelemetry-api
  - opentelemetry-sdk
  - opentelemetry-exporter-otlp
  - opentelemetry-exporter-jaeger
  - opentelemetry-exporter-zipkin
  - opentelemetry-proto
  - opentelemetry-propagator-b3
  - opentelemetry-propagator-jaeger
  + Changed
  - Tracer and Meter provider environment variables are now consistent with the rest (#1571])
  - Rename TRACE_ to TRACES_ for environment variables (#1595])
  - Read-only Span attributes have been moved to ReadableSpan class (#1560)
  + Added
  - Added end_on_exit argument to start_as_current_span (#1519])
  - Add Span.set_attributes method to set multiple values with one call (#1520)
  - Make sure Resources follow semantic conventions (#1480)
  - Allow missing carrier headers to continue without raising AttributeError (#1545)
  + Removed
  - Remove Configuration (#1523)
  - Remove Metrics as part of stable, marked as experimental (#1568)
* Fri Jan 22 2021 Benjamin Greiner <code@bnavigator.de>
- aiocontextvars is only needed for older Python 3.6. Python 3.7
  and beyond provide everything in stdlib contextvars. See
  upstreams' setup.cfg.  Use rpm boolean dependencies to pull in
  aiocontextvars only for python36 if available (TW) or python3 if
  python3-base < 3.7 (Leap)
* Fri Jan 22 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 0.17b0
  + Added
  - Add support for OTLP v0.6.0 (#1472)
  - Add protobuf via gRPC exporting support for Jaeger (#1471)
  - Add support for Python 3.9 (#1441)
  - Added the ability to disable instrumenting libraries specified by
    OTEL_PYTHON_DISABLED_INSTRUMENTATIONS env variable, when using
    opentelemetry-instrument command. (#1461)
  - Add `fields` to propagators (#1374)
  - Add local/remote samplers to parent based sampler (#1440)
  - Add support for OTEL_SPAN_{ATTRIBUTE_COUNT_LIMIT,EVENT_COUNT_LIMIT,LINK_COUNT_LIMIT}
    (#1377)
  - Return `None` for `DictGetter` if key not found (#1449)
  - Added support for Jaeger propagator (#1219)
  - Remove dependency on SDK from `opentelemetry-instrumentation` package. The
    `opentelemetry-sdk` package now registers an entrypoint `opentelemetry_configurator`
    to allow `opentelemetry-instrument` to load the configuration for the SDK (#1420)
  - `opentelemetry-exporter-zipkin` Add support for array attributes in Span and
    Resource exports (#1285)
  - Added `__repr__` for `DefaultSpan`, added `trace_flags` to `__repr__` of
    `SpanContext` (#1485)
  - `opentelemetry-sdk` Add support for OTEL_TRACE_SAMPLER and OTEL_TRACE_SAMPLER_ARG
    env variables (#1496)
  - Adding `opentelemetry-distro` package to add default configuration for
    span exporter to OTLP (#1482)
  + Changed
  - `opentelemetry-exporter-zipkin` Updated zipkin exporter status code and error tag
    (#1486)
  - Recreate span on every run of a `start_as_current_span`-decorated function (#1451)
  - `opentelemetry-exporter-otlp` Headers are now passed in as tuple as metadata, instead of a
    string, which was incorrect. (#1507)
  - `opentelemetry-exporter-jaeger` Updated Jaeger exporter status code tag (#1488)
  - `opentelemetry-api` `opentelemety-sdk` Moved `idsgenerator` into sdk (#1514)
  - `opentelemetry-sdk` The B3Format propagator has been moved into its own package:
    `opentelemetry-propagator-b3` (#1513)
  - Update default port for OTLP exporter from 55680 to 4317 (#1516)
  - `opentelemetry-exporter-zipkin` Update boolean attribute value transformation (#1509)
  - Move opentelemetry-opentracing-shim out of instrumentation folder (#1533)
  - `opentelemetry-sdk` The JaegerPropagator has been moved into its own package:
    `opentelemetry-propagator-jaeger` (#1525)
  - `opentelemetry-exporter-jaeger`, `opentelemetry-exporter-zipkin` Update
    InstrumentationInfo tag keys for Jaeger and Zipkin exporters (#1535)
  - `opentelemetry-sdk` Remove rate property setter from TraceIdRatioBasedSampler (#1536)
  - Fix TraceState to adhere to specs (#1502)
  + Removed
  - `opentelemetry-api` Remove ThreadLocalRuntimeContext since python3.4 is not supported.
- from version 0.16b1
  + Added
  - Add meter reference to observers (#1425)
- from version 0.16b0
  + Added
  - Add optional parameter to `record_exception` method (#1314)
  - Add pickle support to SpanContext class (#1380)
  - Add instrumentation library name and version to OTLP exported metrics (#1418)
  - Add Gzip compression for exporter (#1141)
  - Support for v2 api protobuf format (#1318)
  - Add IDs Generator as Configurable Property of Auto Instrumentation (#1404)
  - Added support for `OTEL_EXPORTER` to the `opentelemetry-instrument` command
    (#1036)
  + Changed
  - Change temporality for Counter and UpDownCounter (#1384)
  - OTLP exporter: Handle error case when no credentials supplied (#1366)
  - Update protobuf versions (#1356)
  - Add missing references to instrumented packages (#1416)
  - Instrumentation Package depends on the OTel SDK (#1405)
  - Allow samplers to modify tracestate (#1319)
  - Update exception handling optional parameters, add escaped attribute to record_exception
    (#1365)
  - Rename `MetricRecord` to `ExportRecord` (#1367)
  - Rename `Record` to `Accumulation` (#1373)
  - Rename `Meter` to `Accumulator (#1372)
  - Fix `ParentBased` sampler for implicit parent spans. Fix also `trace_state`
    erasure for dropped spans or spans sampled by the `TraceIdRatioBased` sampler.
    (#1394)
- See upstream CHANGELOG.md for the changes from 0.7b1 to 0.15b0
  + https://raw.githubusercontent.com/open-telemetry/opentelemetry-python/master/CHANGELOG.md
- Drop tests.tar.bz2 tarball as tests are included in the upstream source now
* Wed Apr 15 2020 pgajdos@suse.com
- version update to 0.6b0
  * Add support for lazy events and links (#474)
  * Metrics API no longer uses LabelSet (#527)
  * Adding is_remote flag to SpanContext, indicating when a span is remote (#516)
  * Allow digit as first char in vendor specific trace state key (#511)
* Fri Mar 27 2020 pgajdos@suse.com
- version update to 0.5b0
  * W3C Correlation Context Propagation
  * OpenTelemetry Collector Exporter Integration for both metrics and traces
  * Metrics SDK
  * Global configuration module
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4a1:
  * various minor tweaks
* Sat Feb 22 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.4a0
